
class distro::redhat inherits box {

	$secretcnf="/etc/davfs2/secrets"
	$davfscnf="/etc/davfs2/davfs2.conf"
	$davurl="https://dav.box.com/dav"
	$fstab="/etc/fstab"

	if $mounted == "true" {
		$mounted = "mounted"
	} else {
		$mounted = "unmounted"
	}

	if $operatingsystem != "Fedora" {
        	case $architecture {
	 		"x86_64", "i386": { $arch = $architecture }
	        	default: { fail("Unrecognized machine architecture ${architecture}") }
		}

		case $operatingsystemrelease {
			/^5.*/: { $el="el5" }
			/^6.*/: { $el="el6" }
			default : { fail("Unrecognized operating system release ${operatingsystemrelease}") }
		}

		yumrepo {"rpmforge":
			name       => "rpmforge.davfs",
			baseurl    => "http://apt.sw.be/redhat/${el}/en/\$basearch/rpmforge",
			mirrorlist => "http://mirrorlist.repoforge.org/${el}/mirrors-rpmforge",
			enabled    => "1",
			gpgcheck   => "1",
			gpgkey     => "http://apt.sw.be/RPM-GPG-KEY.dag.txt",
		}

		package {"davfs2":
			ensure    => installed,
			require   => Yumrepo['rpmforge'],
			notify    => [ 
				File["${davfscnf}"],
		      		File["${secretcnf}"],
		      		File["${mountpoint}"],
				],
		}
	} else {
	
        	package {"davfs2":
                	ensure    => installed,
                	notify    => [
                        	File["${davfscnf}"],
                        	File["${secretcnf}"],
                        	File["${mountpoint}"],
                	],
        	}
	
	}

	file {"${davfscnf}":
		ensure  => file,
		owner   => "root",
		group   => "root",
		mode    => "0644",
		content => template("box/davfs2.conf.erb"),
	}

	file {"${secretcnf}":
		ensure  => file,
		owner   => "root",
		group   => "root",
		mode    => "0600",
		content => template("box/secrets.erb"),
	}

	file {"${mountpoint}":
		ensure => directory,
		owner  => "root",
		group  => "root",
		mode   => "0755",
	}

	exec {"umount":
		cwd          => "/tmp",
		path         => "/bin",
		command      => "umount ${mountpoint}",
		refreshonly  => true,
		onlyif       => "mount | grep dav.box.com > /dev/null",
                subscribe    => [ File["${mountpoint}"],
                                  File["${davfscnf}"],
                                  File["${secretcnf}"],
                                ],
	}

	mount {"${mountpoint}":
	  	ensure    => $mounted,
		atboot    => true,
	  	device    => $davurl,
	  	dump      => '0',
	  	fstype    => 'davfs',
	  	options   => 'rw,user,noauto',
	  	pass      => '0',
		remounts  => false,
	  	target    => $fstab,
		require   => Package['davfs2'],
		subscribe => Exec["umount"],
	}
}

